package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````914``#0````<D0```````#0`(``,
M`"@`&``7``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!<````7````!`````$````!````````````````````I`\`
M`*0/```$`````!````$`````$````!`````0``#-)P``S2<```4`````$```
M`0````!`````0````$```-1-``#430``!``````0```!````Y(T``.2=``#D
MG0``0`(``&P"```&`````!````(```#LC0``[)T``.R=``#P````\`````8`
M```$````!````,P!``#,`0``S`$``"@````H````!`````0```!3Y71DS`$`
M`,P!``#,`0``*````"@````$````!````%#E=&2L@```K(```*R```#T````
M]`````0````$````4>5T9```````````````````````````!@```!````!2
MY71DY(T``.2=``#DG0``'`(``!P"```$`````0```"]L:6(O;&0M;75S;"UI
M,S@V+G-O+C$```0````8````!0```$=.50`!``'`!`````$````"``'`!```
M```````1````1P````@````(`````!`0`"5`!(`H`!`$H(8`A(`!```+(`0)
M.(`208H$"`@`````1P```$L```!/````4````%8```!7````6`````````!:
M````6P````````!<````70```%\``````````````&I_FGSJT^\.SMY'+6_%
MWQ\NQ9NVN(WQ#M1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!N^.2
M?%7#/-)GK\QFB`=PTT-%U>PS8MOM%8PES'^IG)O@IP(*:QJ>4*/@^TD`````
M`````````````````0``````````````$@````D``````````````!$```#.
M`0`````````````1````5P$`````````````$@```!```````````````!(`
M``"G`0`````````````2````&```````````````$@```!\`````````````
M`!(```#;`0`````````````2````LP$`````````````$@```/4"````````
M`````"$````H```````````````2````+@``````````````$@```#4`````
M`````````!(```"L`@`````````````2````R@(`````````````$@````T"
M`````````````!(````\```````````````2````DP(`````````````$@``
M`$,``````````````!(```!+```````````````2````I0(`````````````
M$@```%,``````````````!(```!\`@`````````````2````6P``````````
M````$@```&0``````````````"````"\`@`````````````2````@```````
M````````$@```(4``````````````!(```!T`0`````````````6````F@(`
M````````````$@```#H"`````````````!(```",```````````````2````
MDP``````````````(````"P"`````````````!(```!(`P`````````````2
M````]`(`````````````$0```%X"`````````````!(```#A`@``````````
M```2````[`$`````````````$@```/8"`````````````!$```"Q````````
M```````2````90$`````````````$@```+H``````````````"(```#)````
M```````````2````V0(`````````````$@```$H"`````````````!(```#.
M```````````````2````U```````````````(````(<"`````````````!(`
M``#N```````````````2````F`$`````````````$@```/,`````````````
M`"`````/`0`````````````2````;`(`````````````$@```!4!````````
M`````!(```"'`0`````````````2````(P$`````````````$@```#0!````
M`````````!(````(`@`````````````2````&0(`````````````$@```#H!
M`````````````!(```!3`@`````````````2````PP(`````````````$@``
M`+0"`````````````!(````#`@`````````````2````20$`````````````
M$@```/X"`````````````!(```#S`@`````````````A````4`$`````````
M````$@```.X"``"P$P``M0$``!(`"P#(`0``QC<```$````2``P`B@,``-\A
M``"G!0``$@`+`#8$```N*0``7@```!(`"P!G`P```!T```4````2``L`]`,`
M```0```!````$@`(`*T#``"&)P``J`$``!(`"P`:!```!1T``+X!```2``L`
MY0,``"2@````````$``5`'@#```[(0``I````!(`"P"7`P``JAL``#8````2
M``L`GP,``,8@``!*````$@`+`,,#``"9-0``Z@```!(`"P#8`P``PQX``#4`
M```2``L`,00``%"@````````$``5`"T#``"`%0``-P```!(`"P#Z`P``^!X`
M`,0````2``L`S@,``""@```$````$0`4`!,$```DH````````!``%`#J`P``
M914````````0``L`\0,``%$U``!(````$@`+`#8#```0(0``*P```!(`"P!1
M`P``)AP``-H````2``L`)P0``(,V```F`0``$@`+``8$``"\'P``"@$``!(`
M"P``;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`;'-E
M96L`9V5T<&ED`'-T<F-M<`!U;FQI;FL`;65M;6]V90!S=')N8VUP`'-T<G)C
M:'(`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`
M<W1R<W1R`'-T<F-H<@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;U]B87-E<P!R
M96%D;&EN:P!?7V-X85]F:6YA;&EZ90!E>&ET`&-L;W-E`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`<F5A9`!?7W)E9VES=&5R7V9R86UE7VEN9F]?8F%S
M97,`<FUD:7(`7U]S=&%T7W1I;64V-`!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER
M`%]?;'-T871?=&EM938T`'-T<FQE;@!G971U:60`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?
M;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!?9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!0
M97)L7V-R;V%K7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!0
M97)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H
M<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`'-T<F-P>0!R96%D9&ER`'-P<FEN=&8`<W1R9'5P`'-T<G1O:P!P=&AR
M96%D7V%T9F]R:P!F<')I;G1F`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER
M;VX`7U]S=&%C:U]C:&M?9F%I;`!L:6)P97)L+G-O`&QI8F,N;75S;"UX.#8N
M<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?
M8F%S96YA;64`7U]B<W-?<W1A<G0`<VAA7VEN:70`<&%R7V1I<FYA;64`<&%R
M7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]E;F0`
M<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`Y)T`
M``@```#HG0``"````,2?```(````T)\```@```#8GP``"`````"@```(````
M!*````@````(H```"`````R@```(````$*````@````4H```"````""@```(
M````R)\```8"``#,GP``!@,``-2?```&&@``W)\```X>``#@GP``!B(``.2?
M```&*0``Z)\```8L``#LGP``!C$``/"?```&-0``])\```8W``#XGP``!CD`
M`/R?```&/0``Z)X```<!``#LG@``!P0``/">```'!0``])X```<&``#XG@``
M!P<``/R>```'"````)\```<)```$GP``!PH```B?```'#```#)\```<-```0
MGP``!PX``!2?```'#P``&)\```<0```<GP``!Q$``""?```'$@``))\```<3
M```HGP``!Q0``"R?```'%0``,)\```<6```TGP``!Q<``#B?```'&```/)\`
M``<9``!`GP``!QL``$2?```''```2)\```<=``!,GP``!Q\``%"?```'(```
M5)\```<A``!8GP``!R,``%R?```')```8)\```<F``!DGP``!R<``&B?```'
M*```;)\```<J``!PGP``!RL``'2?```'+0``>)\```<N``!\GP``!R\``("?
M```',```A)\```<R``"(GP``!S,``(R?```'-```D)\```<V``"4GP``!S@`
M`)B?```'.@``G)\```<[``"@GP``!SP``*2?```'/@``J)\```<_``"LGP``
M!T```+"?```'00``M)\```="``"XGP``!T,``+R?```'1```P)\```=&````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#(/$#,,```````````#_LP0```#_HP@`````````_Z,,````:`````#I
MX/____^C$````&@(````Z=#_____HQ0```!H$````.G`_____Z,8````:!@`
M``#IL/____^C'````&@@````Z:#_____HR````!H*````.F0_____Z,D````
M:#````#I@/____^C*````&@X````Z7#_____HRP```!H0````.E@_____Z,P
M````:$@```#I4/____^C-````&A0````Z4#_____HS@```!H6````.DP____
M_Z,\````:&````#I(/____^C0````&AH````Z1#_____HT0```!H<````.D`
M_____Z-(````:'@```#I\/[___^C3````&B`````Z>#^____HU````!HB```
M`.G0_O___Z-4````:)````#IP/[___^C6````&B8````Z;#^____HUP```!H
MH````.F@_O___Z-@````:*@```#ID/[___^C9````&BP````Z8#^____HV@`
M``!HN````.EP_O___Z-L````:,````#I8/[___^C<````&C(````Z5#^____
MHW0```!HT````.E`_O___Z-X````:-@```#I,/[___^C?````&C@````Z2#^
M____HX````!HZ````.D0_O___Z.$````:/````#I`/[___^CB````&CX````
MZ?#]____HXP```!H``$``.G@_?___Z.0````:`@!``#IT/W___^CE````&@0
M`0``Z<#]____HY@```!H&`$``.FP_?___Z.<````:"`!``#IH/W___^CH```
M`&@H`0``Z9#]____HZ0```!H,`$``.F`_?___Z.H````:#@!``#I</W___^C
MK````&A``0``Z6#]____H[````!H2`$``.E0_?___Z.T````:%`!``#I0/W_
M__^CN````&A8`0``Z3#]____H[P```!H8`$``.D@_?___Z/`````:&@!``#I
M$/W___^CQ````&AP`0``Z0#]____H\@```!H>`$``.GP_/___Z/,````:(`!
M``#IX/S___^CT````&B(`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````
M:)@!``#IL/S___^CW````&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D
M````:+`!``#I@/S___^C!`$``&:0_Z,,`0``9I#_HQ0!``!FD```````````
MC4PD!(/D\/]Q_(U!"%6)Y5=6B<Y3Z.T!``"!PQ*+``!1@^P<4(U!!%!1Z&'^
M__^+@R`!``"#Q`Q04/^S'`$``.CK_/__BX/P````@\00B[L``0``@#@`=2_H
MHOW__XF#<`$``(7`=0J#[`QJ`>@N_O__@^P,4.B%_O__98L'@\00QH!W!@``
M`&6+!X"(R@(```.+!HUX`X/`!(E]Y#W___\_=@7HQ_W__X/L#,'@`E#H*_[_
M_XM.!(LV@\00B8-L`0``BQ&)$(V3R:/__XE0!(N31`$``(E0"(V3S*/__XE0
M#+H!````.=9^"HL\D8E\D`Q"Z_*Z$````(7V?@>-%+4,````@^P,,<F)#!!J
M`%"-@P1]____=>10_[-P`0``Z(O\__^#Q"")QH7`=1.#[`S_LW`!``#HA/W_
M_X/$$(G&@^P,_[-P`0``Z`']__^-@[FA___HD`(``(/$$(7`=3"#NV@!````
M=1&-@VZA___H=0(``(F#:`$``(N#:`$``(7`=`R#[`Q0Z/`3``"#Q!"#[`S_
MLW`!``#H`?[__^C<^O__@\00C67PB?!96UY?78UA_,,Q[8G@@^3P4%#H````
M`($$)'F(``!0Z`````!3Z#$```"!PU:)``"#[!"+1"08:@"-4`3_L_0```#_
ML_P```!2_S#_L^@```#H7OS__X/$*%O#BQPDPV:09I"0Z$4!``"!PA>)``"-
MBD@!``"-@D@!```YR'0=BX+X````A<!T$U6)Y8/L%%'_T(/$$,G#C70F`)##
MC;0F`````.@%`0``@<+7B```58GE4XV*2`$``(V"2`$``(/L!"G(B</!Z!_!
M^P(!V-'X=!2+DA`!``"%TG0*@^P(4%'_TH/$$(M=_,G#C;0F`````&:058GE
M4^A>____@<.#B```@^P$@+M(`0```'5#BY,,`0``A=)T$8/L#/^S)`$``.@5
M_?__@\00Z#7___^+@P0!``"%P'02@^P,C8,4X___4.CL_/__@\00QH-(`0``
M`8M=_,G#C;0F`````(VV`````%7H`````%J!PA:(``")Y5/HXO[__X'#!X@`
M`(/L!(N#%`$``(7`=!F-@TP!``!2:@!0C8,4X___4.BB_/__@\00BUW\R>GV
M_O__BQ0DPU575C'V4^B>_O__@</#AP``@^P<B50D!(7`=&:)P8N#"`$``#'V
MB<V+$(72=%2*10"$P'0'/#UT`T7K\BG-B=>+-X7V=#R)5"0,4%51B4PD%%;H
MR_G__X/$$(M,)`B+5"0,A<!U%X`\+CUU$8M$)`0IUXUT+@'!_P*)..L%@\<$
MZ[Z#Q!R)\%M>7UW#@^P<98L5%````(E4)`PQTHU4)`CH6____XM4)`QE*Q44
M````=`7HZ!\``(/$',/H//___X'"#H<``%93B<.#[!1EH10```")1"0,,<"+
ML@@!``"-5"0(B=CH%O___X7`=!>+!HM4)`B-!)"+4`2)$(72=-^#P`3K\HM$
M)`QE*P44````=`7HB!\``(/$%%M>PU:)QE/H@_W__X'#J(8``('LK````&6A
M%````(F$)*0````QP(U$)!105NBV^O__@\00A<!U,8M4)!R!X@#P``"!^@!`
M``!T"('Z`*```'494%!J`E;HV_?__X/$$(7`#Y3`#[;`ZP(QP(N4))P```!E
M*Q44````=`7H!!\``('$I````%M>PU57B<=64^CZ_/__@<,?A@``@>R\````
M9:$4````B80DK````#'`A?\/A`8!``"`/P`/A/T```"#[`Q7Z"[W__^)1"04
M@\00A<`/A.4```"-@R6A__^)1"0(C8,DH?__B40D#(/L#/]T)!#HK_?__X/$
M$(7`#X2C````C7`34E+_="005NB%]___@\00A<!TTU!0_W0D%%;H<O?__X/$
M$(7`=,"#[`Q7Z`+Z__^)-"2)Q>CX^?__C40%`HD$).B<]___5HG%C8,GH?__
M5U!5Z+OY__^#Q!B-1"0D4%7H/?G__X/$$$!T&8M$)"PE`/```#T`0```=0F)
MZ.@"____ZPR#[`Q5Z$7W__^#Q!"#[`Q5Z#GY__^#Q!#I1O___X/L#/]T)!#H
ME??__XD\).C=^/__@\00BX0DK````&4K!10```!T!>BR'0``@<2\````6UY?
M7<-55U:)UE/HIOO__X'#RX0``(/L+(E$)`1EH10```")1"0<,<"`.CUU`4:#
M[`Q6Z"?Y__^#Q!")1"0(BT0D!(U4)!CHP?S__XG'A<!T*H/L#%#H!/G__XM,
M)!B#Q!`YR`^"JP```#'`BA0&B!0'0(32=?7I$P$``(N#"`$``#'_BPB#/+D`
M=`-'Z_>#NV0!````C2R]"````'0=4%!54>B7]?__BY,(`0``@\00B0*%P'5,
MZ=,```")3"0,@^P,5<>#9`$```$```#H//;__X/$$(G"A<`/A*\```"-1?A1
M4(M,)!114HE4)!SH*_;__XM4)!R+@P@!``"#Q!")$(N#"`$``#'2B7PD&(L`
MB50H_(M$)`2*$(32=`B`^CUT`T#K\HNK"`$``(M\)!B#[`R+50"-%+J)5"08
MBTPD$"G(BTPD%(U$`0)0Z+WU__^+5"0<@\00B0*%P'0PBT4`BP2X_T0D!(M\
M)`2)P4"*5_^(4/^`^CUT!(32=>;&`3TQTHH,%H@,$$*$R77UBT0D'&4K!10`
M``!T!>@+'```@\0L6UY?7<-3Z`?Z__^!PRR#``"#[`B-@\3A__]0C8,MH?__
M_[,8`0``4(N#``$``&7_,.A%]___@\086\-64^C0^?__@</U@@``@^P0B[,`
M`0``9?\VZ*S___]8C8/(H___6FH`4%"-@ZJ(__]0C8-)H?__4&7_-NA@]/__
M@\0D6U[#55=64^B(^?__@<.M@@``@>P<(```9:$4````B80D#"```#'`Z&'T
M__^#[`R-DUZA__]24(V#8J'__U!H`1```(UL)"95Z`#T__^#Q""-4`&!^@$0
M``!V`@\+0'4$,<#K65!H`!```(VT)!,0``!65>B5]?__@\00B<6%P'C?@^P,
MC4`!4.A@]/__@\00A<!TS#GP<P>-%"@YUG*\.<9S!XT4+CG0<K&!_0$0``!_
MJ?R)QXGI\Z3&!"@`BY0D#"```&4K%10```!T!>BX&@``@<0<(```6UY?7</I
M(?___U575E/HJ?C__X'#SH$``('LO!```&6A%````(F$)*P0```QP(NT)-`0
M``"+O"34$```C8-NH?__Z%CZ__^)!"1556HO5NB!]/__@\00A<!T$HGRC8-W
MH?__Z*/\___I.0$``(/L#(VKA*'__U?H"?3__UI955#HL/7__X/$$(G'C8,E
MH?__B40D!(V#AJ'__XE$)`B%_W2Y@#\`=02+?"0$@SPD`'074%!7_W0D#.@(
M\___@\00A<`/A,H```"#[`Q7Z)3U__^#Q!"-1`?_.<=S"X`X+W4&Q@``2.OQ
M@^P,5^AU]?__B30DB40D'.AI]?__BU0D'(/$$(U$`@$]_P\```^'2?___U!0
MC8-JHO__5O]T)!174&@`$```C;PDR````%?H0O+__X/$($`]`!```'8"#PM1
M48U$)"105^B(]/__@\00A<!U/HM$)"PE`/```#T`@```=2Y24FH!5^CW\?__
M@\00A<!U'8GZC8-WH?__Z(G[__^#[`Q7Z/KR__^#Q!")QNL44%!5:@#HF?3_
M_X/$$(G'Z?C^__^+A"2L$```92L%%````'0%Z/<8``"!Q+P0``")\%M>7UW#
M5E/H[?;__X'#$H```(/L#(MT)!AJ+U;H<?+__X/$$(7`=`.-<`&#[`Q6Z([R
M__^#Q!1;7L-64^BX]O__@</=?P``@>P4$```9:$4````B80D#!```#'`B[0D
M(!```(7V=%J`/@!T58/L#%;H+?3__X/$$(U0`3'`@?H`$```=UM24E:-="08
M5NCP\?__B30DZ`CT__^#Q!"-1`;_.<9S"X`X+W4&Q@``2.OQ4%!J+U;HV/'_
M_X/$$(7`=0R#[`R-@R6A__]0ZPLYQG,#Q@``@^P,5NCE\?__@\00BY0D#!``
M`&4K%10```!T!>CZ%P``@<04$```6U[#55=64^CR]?__@<,7?P``@^P<C8.(
MH?__C;MNH?__Z.KW__^-@Y&A__^-L\6A___HV??__XV#F:'__XVKSZ'__^C(
M]___C8.BH?__Z+WW__^-@ZFA__^)1"0,Z*[W__^-@[FA___HH_?__XGXZ)SW
M__^)\.B5]___B>CHCO?__XV#V:'__^B#]___C8-WH?__Z'CW__^-@^.A___H
M/O?__X7`=`F)PHGHZ)WY__^-@_2A___H)O?__XG"A<!T"XV#!J+__^B!^?__
MC8,1HO__Z`KW__^)PHGXA=)U$XV#(:+__^CW]O__B<*%P'0'B?#H5OG__XM$
M)`R#Q!R-DS*B__];7E]=Z4#Y__]3Z.OT__^!PQ!^``"#[`B#NT`!``#_=2>-
M@\6A___HL?;__S'2A<!T$(H`/#`/E<$QTH3`#Y7"(<J)DT`!``"+@T`!``"#
MQ`A;PU/HH?3__X'#QGT``(/L".A<\O__@^P,4.C#\/__@\00A<!T`HL`@\0(
M6\-55U93Z'/T__^!PYA]``"#[!R+="0PC8,THO__B40D".@Z]O__A<!T!X`X
M`(G%=0N+1"0(B?*#Q!SK6%!05E7H(?#__X/$$(7`=5&#[`Q6Z-'Q__^)+"2)
MQ^C'\?__C40'`HD$).AK[___B2PDB<*-@X2A__]0C8-JHO__5E!2B50D+.A]
M\?__BU0D+(M$)"B#Q#Q;7E]=Z2_X__^#Q!Q;7E]=PU6Y!@```%=6,?93Z,CS
M__^!P^U\``"!["R!``"+A"1`@0``C;PDQ````(E$)`AEH10```")A"0<@0``
M,<"-@TNB__^)M"2T````C;,H`0``B80DK````(V#):'__XF$)+````#\\Z4Q
M_XV#4*+__XF\),````")A"2X````C8-5HO__B80DO````(V#;J'__^@F]?__
MA<!T'X`X`(G&=!B#[`Q0Z+/^__^)-"3H\.[__XG%Z<H$``#H=/[__XVT)+@`
M``")QX7`=3&+!H7`="7HYO3__X7`=!>`.`!T$H/L#%#HNN[__X/$$(G'A<!U
M"X/&!.O5C;M$HO__@^P,5^A]\/__C40``8D$).@A[O__@\00C9->HO__B<:)
MQ0^V!X3`=!I11U!2B50D$%6#Q0+H+/#__X/$$(M4)`3KWXV\),0```"++X7M
M="F)Z.AI]/__B<6%P'0E@#@`="#HZO3__X7`=!>#[`Q5Z#+N__^#Q!")Q8V\
M)*P```#K-(/'!.O#BQ>%TG0O@#H`="R)T(E4)`2-?P3HL?3__XM4)`2%P'3?
M@^P,4NCU[?__@\00B<6%[73-ZP(Q[8/L#%7HO^___XDT)(G'Z+7O__^-O`<$
M!```B3PDZ%;M__^)1"046(V#8Z+__UI64(V#AJ'__U"-@VBB__]54/]T)"#H
M8.___X/$&&C``0``_W0D$.C_[O__@\000'4SZ.3N__^+`(/X$70G@^P,4/]T
M)!2+1"0<_S"-@W&B__]0BX/L````_S#H.^[__X/$(.M,556-1"0D4/]T)!#H
MUN[__XE$)!R#Q!"%P'40BT0D+"4`\```/0!```!T*/]T)`2+1"0,_S"-@ZRB
M__]0BX/L````_S#H[>W__X/$$#'MZ><"``"+="0TZ/KN__\YQG7+BT0D+"7_
M`0``/<`!``!UNX/L#%?H;>S__XG%C8,_HO__Z.KR__^#Q!"%P'4(BT0D"(LP
MZQ=65E"+1"04_S#H./C__X/$$(G&A<!TX8/L#%;H@>[__X/$$(G'@_@#=EZ-
M@_^B__]145"-1#[\4.C$Z___@\00A<!U1(/_!'0'@'P^^R]U.(M$)`B+>`2%
M_W0M@^P,5^@][O__@\00@_@#=AR-1`?\4E*-DP2C__]24.B"Z___@\00A<!U
M`HG^Z'K[__^)1"0(A<`/A6(!``!04&H`5N@N[/__@\00B<:%P`^$2P$``&H"
M:O]J[E#H)>O__X/$#&H&C;PD)`$``%=6Z!+M__^#Q!"`O"0<`0```'51@+PD
M'0$``$-U1X"\)!X!``!!=3V`O"0?`0``0W4S@+PD(`$``$AU*8"\)"$!``!%
M=1]J`FK_:L96Z,?J__^#Q`QJ*5=6Z+OL__]>6.FF````:@!J`&H`5NBHZO__
MZ%0/``")QX/$$%%H`(```(V4)"0!``!2B50D&%;HANS__X/$$(M4)`R%P'X+
M45!25^AK#P``Z\^#[`Q6Z$?L__]86E>-M"3K````5N@Z$```@\00C9->HO__
M5XM$)`P/M@0&4%*+1"04`<"-O"3_````B50D&`'X4.C*[/___T0D&(/$$(M4
M)`R#?"0(%'7*QH0D&P$```!65HV#R*/__U"-@X:A__]74(V#":/___]T)!A0
M5>B.[/__@\0@Z88```"-DS*B__^-@\6A___H._/__XV[R*/__XVSAJ'__^C4
MZ?__45%74(V#&*/__U;_="084%7H3NS__X/$((V#)J/__XE$)`A04&C``0``
M5>CDZ___@\000'4NZ,GK__^#.!%U)/]$)`SHB^G__U)7_W0D%%!6_W0D&/]T
M)"!5Z`7L__^#Q"#KOX/L#/]T)!#HM.O__XGJC8-NH?__Z*WR__^)+"3HVOG_
M_X/$$(N$)!R!``!E*P44````=`7H-!```('$+($``(GH6UY?7<-55U93Z"CN
M__^!PTUW``"#[`R+LP`!``!EBP:*4&2(4&6-@ZFA___HZ.___X7`=`N`.#%U
M!H!X`0!T!>CV]___C8-#H___:@-J`5!E_S;HY^G__X/$$(G'A<!T,8V#1:/_
M_U50BT<,_S!E_S;HZ>G__XM'#(/$$(L`]D`*0'0.45%09?\VZ.#H__^#Q!"-
M@TJC__]J`VH!4&7_-NB:Z?__@\00B<6%P'10C8-WH?__Z&#O__^%P'0'4E"+
M10SK+>C<\___A<")QXM%#'0655?_,&7_-NB!Z?__B3PDZ)GJ___K$XN3;`$`
M`%'_,O\P9?\VZ&3I__^#Q!"-@TRC__]2:@%09?\VZ+_G__^#Q`R-DV&C__]2
M4&7_-N@\Z?__98L&QD!E`(V#;J'__^CD[O__@\00B8-H`0``A<!U)H/L#/^S
M;`$``.@.^?__@\00B8-H`0``A<!U"X/L#(V#9Z/__^LW4%!HP`$``/^S:`$`
M`.CUZ?__@\00C5`!@_H!=B"#^!%T&U"+@VP!``#_LV@!``#_,(V#B*/__U#H
M:N?__X/$#%M>7UW#5U93BW0D$.A][/__@<.B=0``@^P,5NBO]?__B00DZ'+U
M__^)Q^AN]___@\00A<!T*87V="6`/@!T(%!0C8-CHO__4%?H*>C__X/$$#G'
M=0I;B?!>7^DJ[___6UY?PU4QTE=64X'L?`$``(E$)`AEH10```")A"1L`0``
M,<"+1"0(BTR0'(U$)"P/R8D,D$*#^A!UZ8V,)"P!``"+4#0S4""#P`0S4`0S
M4/S1PHE0/#G(=>B+1"0(BP")1"00BT0D"(M`!(E$)!B+1"0(BUPD&(M`"(E$
M)`R+1"0(BU0D#(ML)`R+0`R)1"04BT0D"(M,)!2+0!")1"0<BT0D+(MT)!R-
MM`:9>8):BT0D$,'`!0'&BT0D##'((=@QR(M,)`P!QHG8BUPD$,'(`C'"(=J+
M7"04,<J+3"0PC;P+F7F"6HM,)!"+7"0T`=>)\L'"!<')`HV<'9EY@EJ+;"0X
M`=>)PC'*(?+!S@(QPHV$*)EY@EJ+;"0\`=.)^L'"!0'3B<HQ\B'ZP<\",<J-
MC"F9>8):B?T!T(G:P<(%`=")\C'Z(=HQ\@'1B<+!P@7!RP(!T3'=BU0D0"'%
MP<@",?V-E!:9>8):B<X!ZL'&!8G=`?(QQ8G&BT0D1"'-,=V-A`>9>8):B=<!
MZ,''!8GU`?B)SXM,)$C!SP(Q_8V,"YEY@EJ)PR'5P<,%,?4!Z8G]`=F)TXM4
M)$S!RP(QW8V4%IEY@EJ)SB'%P<8%,?W!R`(!ZHG=`?(QQ8G&BT0D4"'-,=V-
MA`>9>8):B=<!Z,''!8GU`?B)SXM,)%3!SP(Q_8V,"YEY@EJ)PR'5P<,%,?4!
MZ8G]`=F)TXM4)%C!RP(QW8V4%IEY@EJ)SB'%P<8%,?W!R`(!ZHG=`?(QQ8G&
MBT0D7"'-,=V-A`>9>8):B=<!Z,''!8GU`?B)SXM,)&#!SP(Q_8V,"YEY@EJ)
MPR'5P<,%,?4!Z8G]`=F)TXM4)&3!RP(QW8V4%IEY@EJ)SB'%P<8%,?W!R`(!
MZHG=`?(QQ8G&BT0D:"'-P<D",=V-A`>9>8):B=<!Z,''!8GU`?@QS8M\)&PA
MU<'*`C'UC;P[F7F"6HG#`>_!PP6+;"1P`=^)RS'3C;0NF7F"6HG5(</!R`(Q
MRS'%`=Z)^R']P<,%`=Z+7"1T,=7!SP*-G!F9>8):B?$!Z\'!!8G%`<LQ_8M,
M)'@A]<'.`C'%C8P*F7F"6HG:`>G!P@4!T8M4)'R-A!"AZ]ENB?HQ\C':P<L"
M`<*)R,'`!0'"BX0D@````(V\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,)(0`
M``#!SP*-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+E"2(````P<X"C9P3H>O9
M;HGZ,?(QP@':B<O!R`+!PP4!VHG#BX0DC````(V\!Z'KV6Z)\#'8,<@!^(G7
MP<<%`?B)SXN,))````#!SP*-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+E"24
M````P<X"C9P3H>O9;HGZ,?(QPL'(`@':B<O!PP4!VHG#BX0DF````(V\!Z'K
MV6Z)\#'8,<@!^(G7P<<%`?B)SXN,))P```#!SP*-M`ZAZ]ENB=DQ^3'1`?&)
MQL'&!0'QB=:+E"2@````P<X"C9P3H>O9;HGZ,?(QPL'(`@':B<O!PP4!VHG#
MBX0DI````(V\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,)*@```#!SP*-M`ZA
MZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+E"2L````P<X"C9P3H>O9;HGZ,?(QPL'(
M`@':B<O!PP4!VHG#BX0DL````(V\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,
M)+0```#!SP*-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+E"2X````P<X"C9P3
MH>O9;HGZ,?(QPL'(`@':B<O!PP4!VHG#BX0DO````(V\!Z'KV6Z)\#'8,<@!
M^(G7P<<%`?B)SXN,),````#!SP*-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+
ME"3$````P<X"C9P3H>O9;HGZ,?(QPL'(`HG%`=J+A"3(````B<O!PP4!VHV<
M!Z'KV6Z)\(GO,>@QR`'8B=/!R0+!PP4ASP'8B>L)RR'3P<H""=^+G"3,````
MC9P>W+P;CXG&`?O!Q@6)SP'S"=>)SB''(=;!R`()_HN\)-````"-O#W<O!N/
MB=4!]XG>(<7!Q@4!]XG6"<8AWL'+`@GUB[0DU````(VT,=R\&X^)^0'NP<$%
MB=V)PP'.">N)P2'[(>D)V8N<)-@```"-G!K<O!N/B?(!R\'/`HGIP<(%"?D!
MTXGJ(?'!S@(A^@G*BXPDW````(V,"-R\&X^)V`'1P<`%B?H!P0GRB?@AVB'P
MP<L""="+E"3@````C905W+P;CXGU`<*)R"'=P<`%`<*)\`G8(<@)Q8N$).0`
M``"-A`?<O!N/B=<!Z,''!8G=`?B)SXG9P<\""?DA_2'1"<V+C"3H````C8P.
MW+P;CXG&`>G!Q@6)_0'QB=:)^L'.`@GR(?4APL'(`@G5BY0D[````(V4$]R\
M&X^)RP'JP<,%B?4!VHG#B?`)V"'=(<@)Q8N$)/````"-A`?<O!N/B=<!Z,''
M!8G=`?B)SXG9P<\""?DA_2'1"<V+C"3T````C8P.W+P;CXG&`>G!Q@6)_0'Q
MB=:)^L'.`@GR(?4AP@G5BY0D^````(V4$]R\&X^)RP'JP<,%B?7!R`(!VHG#
MB?`)V"'=(<@)Q8N$)/P```"-A`?<O!N/B=<!Z,''!8G=`?B)SXG9P<\""?DA
M_2'1"<V+C"0``0``C8P.W+P;CXG&`>G!Q@6)_0'QB=:)^L'.`@GR(?4APL'(
M`@G5BY0D!`$``(V4$]R\&X^)RP'JP<,%B<6)\`':">B)\R'((>L)PXN$)`@!
M``"-A`?<O!N/B>\!V(G3P<D"P<,%(<\!V(GK"<LAT\'*`@G?BYPD#`$``(V<
M'MR\&X^)Q@'[P<8%B<\!\XG.(=<)UB'&P<@""?>+M"00`0``C;0UW+P;CXG5
M`?Z)WPG%P<<%(=W!RP(!_HG7(<<)[XNL)!0!``"-C"G<O!N/B<4!^8GW"=W!
MQP4A]0'YB<<AWPGOBZPD&`$``(V4*MR\&X\!UXG*P<X"P<(%`=>+E"0<`0``
MC900UL%BRHG8,?`QR,')`@'0B?K!P@4!T(N4)"`!``"-G!/6P6+*B?(QRC'Z
MP<\"`=J)P\'#!0':BYPD)`$``(VT'M;!8LJ)RS'[,</!R`(!\XG6P<8%`?.)
MQHN$)"@!``"-C`'6P6+*B?@Q\#'0`<B)V<'!!0'(B=&+E"0L`0``P<D"C907
MUL%BRHGW,<\QWP'7B<+!P@4!UXN4)#`!``#!RP*-M!;6P6+*B<HQVC'"P<@"
M`?*)_L'&!0'RB<:+A"0T`0``C80!UL%BRHG9,?$Q^<'/`@'!B=#!P`4!P8N$
M)#@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"0\`0``P<L"C906UL%B
MRHG^,=XQSL')`@'6B<+!P@4!UHN4)$`!``"-O!?6P6+*B=HQRC'"P<@"`?J)
M]\''!0'ZB<>+A"1$`0``BVPD$(V$`];!8LJ)RS'[,?/!S@(!PXG0P<`%`<.+
MA"1(`0``C8P!UL%BRHGX,?`QT`'(B=G!P04!R(G1BY0D3`$``,')`HV4%];!
M8LJ)]S'/,=_!RP(!UXG"P<(%`=>+E"10`0``C;06UL%BRHG*,=HQPL'(`@'R
MB?[!Q@4!\HG&BX0D5`$``(V$`=;!8LJ)V3'Q,?G!SP(!P8G0P<`%`<&+A"18
M`0``C9P#UL%BRHGP,?@QT`'8B<O!PP4!V(G3BY0D7`$``,'+`HV4%M;!8LJ)
M_C'>,<[!R0(!UHG"P<(%`=:+E"1@`0``C;P7UL%BRHG:,<HQPL'(`@'ZB??!
MQP4!^HN\)&0!``"-O#O6P6+*B<LQPS'SP<X"`?N)U\''!0'[B[PD:`$``(V\
M/=;!8LH!SXG!,?$QT<'*`@'YB=_!QP4!^8M\)`B)#XM,)!@!V8G[B4\$BWPD
M#(G9`?J)4PB+7"04C10SBW0D'(E1#`'PB4$0BX0D;`$``&4K!10```!T!>AG
M`@``@<1\`0``6UY?7<-3Z&#@__^!PX5I``"#[!1J8.BIV___,=+'``$C16?'
M0`2)J\WOQT`(_MRZF,=`#'94,A#'0!#PX=+#B5`4B5`8B5!<@\086\-55U93
M@^P<BUPD.(ML)#"+="0TC03=``````-%%',#_T48B444BTU<B=C!Z!T!11B-
M11R)1"0,A<ET2[A`````*<@YV'X"B=B+5"0,`<HY\G,'C0P".<[K"8T,!CG6
M<P<YRG,#_`\+_(G7B<$IP_.DBTU<`<&)35R#^4!U98GHZ&_S___K`?R#^S]^
M+CET)`R-1D!S!XU-7#G.ZPJ+?"0,.?YS!#G'<KV+?"0,N1````"#ZT#SI8G&
MZ\.+1"0,.70D#',&`=@YQNL+.<9S"8T$'CE$)`QRCHM\)`R)V?.DB5U<@\0<
M6UY?7</H(0$```54:```55=64X/L'(M<)#2+="0PB40D!(M#%(M3&(G%P>@#
M#\J)5"0(@^`_C5,<#\V->`&)%"3&1`,<@`'Z@_\X?BFY0````"GY_#'`B=?S
MJHG8B4PD#.BH\O__BSPDBT0D#+D.````\ZOK#KDX````*?G\,<")U_.JBT0D
M"(EK6(E#5(G8Z'GR__^+`X/L#,'H&(@&BP/!Z!"(1@&+`XAF`HL#B$8##[9#
M!XA&!`^W0P:(1@6+0P2(9@:+0P2(1@</MD,+B$8(#[=#"HA&"8M#"(AF"HM#
M"(A&"P^V0P^(1@P/MT,.B$8-BT,,B&8.BT,,B$8/#[9#$XA&$`^W0Q*(1A&+
M0Q"(9A*+0Q"(1A-3BUPD%.A?V___@\0L6UY?7<.+!"3#4^@$WO__@<,I9P``
M@^P(Z*_;__^#Q`A;PX/L#(/$#,,`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%2
M7U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)
M3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`#$`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%5315(`55-%4DY!
M344`)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!P87)L`"YP87(`)7,E<V-A
M8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`%1%35!$
M25(`5$U0`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4V`%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F
M<V5T7W-I>F4L("1#04-(15]M87)K97(L("1C86-H95]N86UE7W-I>F4I.PI"
M14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E
M=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;6%R:V5R(#T@(EPP
M0T%#2$4B.PHD8V%C:&5?;F%M95]S:7IE(#T@-#`["GT*<W5B(&9I;F1?<&%R
M7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@
M)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O
M<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X]
M(#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU
M;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I
M;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD<&]S("L]("1I.PIR
M971U<FX@)'!O<SL*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M
M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D
M=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A
M<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP
M6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL
M96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN
M+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@
M/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I
M.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N
M86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ
M0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE
M(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD
M14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R
M=%]P;W,L("1D871A7W!O<RD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O
M9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N
M86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%
M<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A
M<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;
M0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@
M;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U
M9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB
M+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@
M)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE("T@)&]F9G-E="P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY
M("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@
M("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE
M("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D
M8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D[
M"FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@
M*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@
M/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN
M960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2![
M"FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W
M-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL
M96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F
M=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@
M86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H
M(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE
M(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL[
M"GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L
M97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO
M9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O
M<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM
M;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L
M(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M
M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F
M:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=
M.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A
M;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T10
M04XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E
M("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD9FEL96YA;65].PI]"G5N;&5S<R`H)&)U9B!E<2`B4$M<
M,#`S7#`P-"(I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S
M96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C
M('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?
M<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@
M86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*
M;7D@)'!A<E]C;&5A;B`]("(],2(["FUY("1P87-S7W!A<E]C;&5A;B`]('5C
M(")?7W!A<W-?<&%R7V-L96%N7U\B.PHD;&]A9&5R(#U^('-[*#\\/21[<&%S
M<U]P87)?8VQE86Y]*2@@*RE]"GLD<&%R7V-L96%N("X@*"(@(B!X("AL96YG
M=&@H)#$I("T@;&5N9W1H*"1P87)?8VQE86XI*2E]96<["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@
M(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@
M9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@
M(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M
M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*
M96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M
M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N
M*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I
M9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;
M4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC
M;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ
M<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=
M.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C
M:&5?;F%M95]S:7IE.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN
M97<H,2D["F]P96X@;7D@)'1H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F
M:6QE*"1T:"D["F-L;W-E("1T:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S
M:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@)&-A
M8VAE7VUA<FME<CL*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`K(&QE;F=T:"@D
M8V%C:&5?;F%M92D@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64L"G!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD*)B8@
M)&9H+3YC;&]S90IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F
M("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA
M;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;
M9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R
M86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U
M=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O
M<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*
M?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\
M("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@
M+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L
M(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*
M?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@
M1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR
M97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y
M;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E
M<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR
M97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT
M;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(
M86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B
M)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D
M14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE
M;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I
M8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H
M+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H)&-A
M8VAE7VUA<FME<BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H)&-A8VAE7VUA<FME<BD["FEF("@D8G5F(&5Q("1C86-H95]M87)K97(I
M('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM
M(&QE;F=T:"@D8V%C:&5?;6%R:V5R*0HM("1C86-H95]N86UE7W-I>F4L(#`[
M"G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O
M7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D
M9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[
M7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N
M86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM
M;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H
M)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]
M"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.
M04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE
M('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA
M;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T
M<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I
M"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI
M;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P
M87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T]
M(#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%2
M7R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[
M(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC````
M`1L#._`````=````9(___PP!``#DDO__,`$```23___$"P``8I;__T0!``#N
MEO__D`$``!V7__^H`0``?Y?__]0!```&F/__(`(``%J9___H`@``_IK__V@#
M```TF___E`,``'J;___8`P``5)S__U0$``!9G/__:`0``!>>__]L!0``3)[_
M_Z0%```0G___'`8``!J@__]8!@``9*#__W@&``"/H/__I`8``#.A__\D!P``
MVJ;__X@*``""J/__<`L``."H__\,#```I;3__TP,``#MM/__<`P``->U__^L
M#```_;;___`,```!M___!`T``!0``````````7I2``%\"`$;#`0$B`$``"``
M```<````4([__X`#````#@A&#@Q*#PMT!'@`/QH[*C(D(A````!`````K)'_
M_Q@`````````2````%0````6E?__C`````!!#@B%`D$.#(<#00X0A@1##A2#
M!4X.,'<.-$$..$$./$4.0$@.,&L.%$/##A!!Q@X,0<<."$'%#@0``!0```"@
M````5I7__R\`````0PX@:PX$`"@```"X````;97__V(`````3`X(A@)!#@R#
M`T4.(`)-#@Q!PPX(0<8.!```2````.0```"CE?__AP````!!#@B&`D,.#(,#
M40ZX`50.O`%!#L`!2`ZP`5\.M`%!#K@!0@Z\`4$.P`%(#K`!9PX,0<,."$'&
M#@0``,0````P`0``WI7__U0!````00X(A0)!#@R'`T,.$(8$00X4@P51#M`!
M8P[<`4$.X`%,#M`!7P[<`40.X`%(#M`!3`[4`4$.V`%$#MP!00[@`4@.T`%%
M#M0!00[8`40.W`%!#N`!2`[0`4<.W`%!#N`!7`[D`4D.Z`%!#NP!00[P`4@.
MV`%%#MP!00[@`4@.T`%?#MP!00[@`4@.T`%##MP!00[@`4@.T`%(#MP!1`[@
M`5`.T`%;#A1!PPX00<8.#$''#@A!Q0X$?````/@!``!JEO__I`$```!!#@B%
M`D$.#(<#00X0A@1##A2#!4X.0%D.3$$.4$@.0%H.3$$.4$P.0'X.1$$.2$$.
M3$$.4$X.0%(.3$$.4%(.0$X.1$$.2$4.3$$.4%8.0',.3%D.4$P.0`)+#A1!
MPPX00<8.#$''#@A!Q0X$```H````>`(``(Z7__\V`````$$."(,"3@X01PX4
M3`X800X<20X@2`X(0<,.!$````"D`@``F)?__T8`````00X(A@)!#@R#`TX.
M'$D.($8.'$<.&$(.'$$.($$.)$<.*$<.+$,.,$@.#$'##@A!Q@X$>````.@"
M``":E___V@````!!#@B%`D$.#(<#00X0A@1!#A2#!5$.L$!7#KQ`1P[`0$$.
MQ$!'#LA`10[,0$4.T$!(#K!`50ZT0$4.N$!(#KQ`00[`0$@.L$!)#KQ`1`[`
M0$@.L$`"2`X40<,.$$'&#@Q!QPX(0<4.!````!````!D`P``^)?__P4`````
M``````$``'@#``#IE___O@$```!!#@B%`D$.#(<#00X0A@1!#A2#!5$.T"%L
M#M0A00[8(4(.W"%!#N`A2`[0(5D.W"%'#N`A1@[<(4$.V"%!#MPA00[@(4@.
MT"%J#M0A00[8(4$.W"%$#N`A2`[0(4L.W"%!#N`A2`[0(58.W"%!#N`A6`[0
M(5`.U"%!#M@A1P[<(40.X"%!#N0A00[H(44.["%(#O`A2`[0(4L.U"%!#M@A
M10[<(4$.X"%(#M`A50[4(4$.V"%"#MPA00[@(4@.T"%4#MPA00[@(4@.T"%%
M#M0A00[8(4$.W"%"#N`A2`[0(6(.%$/##A!!Q@X,0<<."$'%#@0T````?`0`
M`*.8__\U`````$$."(8"00X,@P-.#AA&#AQ!#B!(#A!*#AQ!#B!(#@Q!PPX(
M0<8.!'0```"T!```H)C__\0`````00X(A@)!#@R#`U$.H"!B#JP@00ZP($@.
MH"!.#J0@00ZH($$.K"!%#K`@4`Z@(%0.I"!!#J@@0@ZL($$.L"!(#J`@1PH.
MK"!'#K`@0@M*#JP@00ZP($@.H"!;#@Q!PPX(0<8.!````#@````L!0``[)C_
M_PH!````00X(A0)!#@R'`T$.$(8$00X4@P5.#C`"Z0X41\,.$$'&#@Q!QPX(
M0<4.!!P```!H!0``NIG__TH`````00X(@P).#A!Y#@A!PPX$*````(@%``#D
MF?__*P````!!#@B#`DX.$$@.'$$.($@.$$D."$'##@0```!\````M`4``..9
M__^D`````$$."(4"00X,AP-!#A"&!$$.%(,%3@XP9PH.%$(+00XT00XX00X\
M00Y`2`XP1PX\00Y`9PY$1PY(00Y,00Y05`X40<,.$$'&#@Q!QPX(0<4.!$4.
M,(,%A0*&!(<#0PX40<,.$$'&#@Q!QPX(0<4.!&`#```T!@``!YK__Z<%````
M00X(A0)&#@R'`T$.$(8$0PX4@P51#L""`@*'"@[,@@)!#M""`E0+:0[,@@)!
M#M""`D@.P(("5`[,@@)!#M""`E0.P(("4@[$@@)"#LB"`D$.S(("10[0@@)+
M#L""`G$.S(("00[0@@)(#L""`G0.S(("00[0@@)(#L""`DT.S(("00[0@@)C
M#LR"`D<.R(("00[,@@)!#M""`D<.U(("1P[8@@)!#MR"`D0.X(("2`[(@@)%
M#LR"`D0.T(("2`[`@@)2#LR"`D$.T(("1`[4@@)&#MB"`D<.W(("2`[@@@)(
M#L""`D,.Q(("00[(@@)%#LR"`D0.T(("3`[`@@)8#L2"`D8.R(("1P[,@@)(
M#M""`D@.P(("9P[,@@)!#M""`E4.P(("30[$@@)!#LB"`D$.S(("1@[0@@)(
M#L""`DD.S(("00[0@@)(#L""`DX.Q(("00[(@@)!#LR"`D4.T(("2`[`@@)>
M#LR"`D$.T(("2`[`@@)*#L2"`D$.R(("1P[,@@)!#M""`D@.P(("6`H.Q(("
M00[(@@)"#LR"`D$.T(("2`[`@@),#L2"`D(.R(("0@[,@@)!#M""`D@.Q(("
M0@[(@@)(#LR"`D$.T(("2`[`@@)^#L2"`D(.R(("0@[,@@)!#M""`D@.Q(("
M0@[(@@)!#LR"`D$.T(("1@[,@@)!#LB"`D4+0@[$@@)"#LB"`D(.S(("00[0
M@@)/#L""`D$.Q(("10[(@@)(#LR"`D4.T(("2`[`@@))#L2"`D$.R(("00[,
M@@)!#M""`D<.P(("0P[,@@)!#M""`D8.S(("00[(@@)!#LR"`D@.T(("2`[`
M@@)'#L2"`DD.R(("00[,@@)4#M""`DP.P(("5`[$@@)!#LB"`D<.S(("1P[0
M@@)!#M2"`DH.V(("00[<@@)!#N""`D@.P((":`[$@@)!#LB"`D$.S(("00[0
M@@)'#M2"`D0.V(("00[<@@)!#N""`D@.P(("2P[$@@)!#LB"`D4.S(("00[0
M@@)(#L""`E<.Q(("00[(@@)$#LR"`D$.T(("00[4@@)$#MB"`D0.W(("00[@
M@@)(#L""`D4.S(("1`[0@@)=#L""`EL.%$/##A!!Q@X,0<<."$'%#@3D````
MF`D``$J<__^H`0```$$."(4"00X,AP-!#A"&!$$.%(,%3@X@=@XD0@XH00XL
M0PXP2`X@30XD00XH10XL0PXP2PX@20XD00XH00XL0PXP2`X@2`H.)$(.*$$.
M+$,.,$@.(%8.)$$.*$4+3PH.)$$.*$(.+$,.,$\+1PXD0@XH0@XL0PXP2`X@
M1PH.)$(.*$$.+$,.,$@.)$<.*$$.+$,.,%H.($T.+$8.,$@.($T.+$@+00XD
M00XH10XL1@XP2`X@3@XD3`XH0@XL1PXP10X@0PX40<,.$$'&#@Q!QPX(0<4.
M!```4````(`*```*G?__7@````!!#@B'`D$.#(8#00X0@P12#AQ!#B!7#A!.
M#A1!#AA'#AQ!#B!(#A!%"L,.#$/&#@A!QPX$10M!PPX,0<8."$''#@0`1```
M`-0*```XA___M0$```!$#`$`3!`%`G4`0A`'`G5\$`8"=7A#$`,"=71,#P-U
M<`8#C`'!#`$`0<-!QD''0<5##`0$````/````!P+``#,G/__Q0L```!!#@B%
M`D,.#(<#00X0A@1!#A2#!48.D`,#M`L.%$'##A!!Q@X,0<<."$'%#@0``"``
M``!<"P``4:C__T@`````00X(@P).#AQ"#B!U#@A!PPX$`#@```"`"P``=:C_
M_^H`````00X(A0)!#@R'`T$.$(8$00X4@P5##C`"W@X40<,.$$'&#@Q!QPX(
M0<4.!$````"\"P``(ZG__R8!````2PX(A0)!#@R'`T$.$(8$00X4@P5##C`"
MA`X\`H`.0$P.%$'##A!!Q@X,0<<."$'%#@0`$``````,```%JO__!```````
M```<````%`P``/6I__\9`````$$."(,"3@X02`X(0<,.!```````````````
M````````````P!8``%`6```!````#P,```$````:`P``#P```$($```,````
M`!````T```#&-P``&0```.2=```;````!````!H```#HG0``'`````0```#U
M_O]O]`$```4```#,"```!@```,P"```*````8`0```L````0````%0``````
M```#````W)X```(```"X`0``%````!$````7````[`T``!$````L#0``$@``
M`,`````3````"````!@`````````^___;P$```CZ__]O#```````````````
M``````````````````````````````````````````#LG0`````````````F
M$```-A```$80``!6$```9A```'80``"&$```EA```*80``"V$```QA```-80
M``#F$```]A````81```6$0``)A$``#81``!&$0``5A$``&81``!V$0``AA$`
M`)81``"F$0``MA$``,81``#6$0``YA$``/81```&$@``%A(``"82```V$@``
M1A(``%82``!F$@``=A(``(82``"6$@``IA(``+82``#&$@``UA(``.82``#V
M$@``!A,``!83```F$P``-A,``$83``!6$P``9A,``'83``"&$P``L!,`````
M````````QC<`````````$```````````````````````````````````````
M`````````````*```.)```#;0```$T(``/A````;0@```````/____^K0@``
M1T-#.B`H06QP:6YE(#$R+C(N,5]G:70R,#(R,#DR-"UR-"D@,3(N,BXQ(#(P
M,C(P.3(T```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N<')O<&5R='D`
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC
M`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````
M````````````````````````"P````$````"````M`$``+0!```7````````
M```````!`````````!,````'`````@```,P!``#,`0``*```````````````
M!``````````F````]O__;P(```#T`0``]`$``-@````$``````````0````$
M````,`````L````"````S`(``,P"````!@``!0````$````$````$````#@`
M```#`````@```,P(``#,"```8`0``````````````0````````!`````"0``
M``(````L#0``+`T``,`````$``````````0````(````20````D```!"````
M[`T``.P-``"X`0``!````!,````$````"````%(````!````!@`````0````
M$```!P```````````````0````````!-`````0````8````0$```$!```(`#
M`````````````!`````$````6`````$````&````D!,``)`3```8````````
M```````(````"````&$````!````!@```+`3``"P$P``%B0`````````````
M$`````````!G`````0````8```#&-P``QC<```<```````````````$`````
M````;0````$````"`````$````!```"J0``````````````$`````````'4`
M```!`````@```*R```"L@```]```````````````!`````````"#`````0``
M``(```"@@0``H($``#0,``````````````0`````````C0````X````#````
MY)T``.2-```$```````````````$````!````)D````/`````P```.B=``#H
MC0``!```````````````!`````0```"E````!@````,```#LG0``[(T``/``
M```%``````````0````(````7`````$````#````W)X``-R.```D`0``````
M```````$````!````*X````!`````P````"@````D```)```````````````
M!`````````"T````"`````,````DH```))```"P```````````````0`````
M````N0````$````P`````````"20```T```````````````!`````0````$`
F```#``````````````!8D```P@```````````````0``````````
